searchData={"items":[{"type":"module","title":"MidiProto","doc":"# MidiProto\n\nSee `MidiProto.Parser` for information about parsing incoming MIDI messages\ninto data structures.\n\nSee `MidiProto.Message` for information about messages and encoding them into\nthe wire.","ref":"MidiProto.html"},{"type":"module","title":"Examples - MidiProto","doc":"Generating a note-on message for middle C and encoding it for transmission:\n\n    iex> MidiProto.Message.NoteOn.init(0, 60, 127)\n    ...> |> MidiProto.Message.encode()\n    <<0x90, 0x3c, 0x7f>>\n\nParsing an incoming packets:\n\n    iex> MidiProto.Parser.init()\n    ...> |> MidiProto.Parser.append(<<0x90, 0x3c, 0x7f>>)\n    ...> |> MidiProto.Parser.parse()\n    {:ok, [%MidiProto.Message.NoteOn{channel: 0, note_number: 60, velocity: 127}], %MidiProto.Parser{}}\n\nGenerating a Firmata message:\n\n    iex> MidiProto.Firmata.FirmwareQuery.init()\n    ...> |> MidiProto.Message.encode()\n    <<0xf0, 0x79, 0xf7>>\n\nConverting a MIDI message into a Firmata message:\n\n    iex> MidiProto.Message.SystemExclusive.init(0x79, \"\")\n    ...> |> MidiProto.Firmata.convert()\n    {:ok, %MidiProto.Firmata.FirmwareQuery{}}","ref":"MidiProto.html#module-examples"},{"type":"type","title":"MidiProto.fourteen_bit_int/0","doc":"","ref":"MidiProto.html#t:fourteen_bit_int/0"},{"type":"type","title":"MidiProto.nybble/0","doc":"","ref":"MidiProto.html#t:nybble/0"},{"type":"type","title":"MidiProto.seven_bit_int/0","doc":"","ref":"MidiProto.html#t:seven_bit_int/0"},{"type":"module","title":"MidiProto.Firmata","doc":"This module converts incoming MIDI messages into Firmata messages if possible.","ref":"MidiProto.Firmata.html"},{"type":"function","title":"MidiProto.Firmata.convert/1","doc":"Given a MIDI message struct, convert it to it's equivalent Firmata message.","ref":"MidiProto.Firmata.html#convert/1"},{"type":"type","title":"MidiProto.Firmata.t/0","doc":"","ref":"MidiProto.Firmata.html#t:t/0"},{"type":"module","title":"MidiProto.Firmata.AnalogMappingQuery","doc":"Represents a Firmata analog mapping query implemented using a MIDI SysEx message.","ref":"MidiProto.Firmata.AnalogMappingQuery.html"},{"type":"function","title":"MidiProto.Firmata.AnalogMappingQuery.init/0","doc":"Initialise a new `AnalogMappingQuery` struct.","ref":"MidiProto.Firmata.AnalogMappingQuery.html#init/0"},{"type":"type","title":"MidiProto.Firmata.AnalogMappingQuery.t/0","doc":"","ref":"MidiProto.Firmata.AnalogMappingQuery.html#t:t/0"},{"type":"module","title":"MidiProto.Firmata.AnalogMappingResponse","doc":"Represents a Firmata analog mapping response using a MIDI SysEx message.","ref":"MidiProto.Firmata.AnalogMappingResponse.html"},{"type":"function","title":"MidiProto.Firmata.AnalogMappingResponse.init/1","doc":"Initialise a AnalogMappingResponse struct.","ref":"MidiProto.Firmata.AnalogMappingResponse.html#init/1"},{"type":"type","title":"MidiProto.Firmata.AnalogMappingResponse.pin_mapping/0","doc":"","ref":"MidiProto.Firmata.AnalogMappingResponse.html#t:pin_mapping/0"},{"type":"type","title":"MidiProto.Firmata.AnalogMappingResponse.t/0","doc":"","ref":"MidiProto.Firmata.AnalogMappingResponse.html#t:t/0"},{"type":"module","title":"MidiProto.Firmata.CapabilityQuery","doc":"Represents a Firmata capability query implemented using a MIDI SysEx message.","ref":"MidiProto.Firmata.CapabilityQuery.html"},{"type":"function","title":"MidiProto.Firmata.CapabilityQuery.init/0","doc":"Initialise a new `CapabilityQuery` struct.","ref":"MidiProto.Firmata.CapabilityQuery.html#init/0"},{"type":"type","title":"MidiProto.Firmata.CapabilityQuery.t/0","doc":"","ref":"MidiProto.Firmata.CapabilityQuery.html#t:t/0"},{"type":"module","title":"MidiProto.Firmata.CapabilityResponse","doc":"Represents a Firmata capability response implemented using a MIDI SysEx message.","ref":"MidiProto.Firmata.CapabilityResponse.html"},{"type":"function","title":"MidiProto.Firmata.CapabilityResponse.init/1","doc":"Initialise a new `CapabilityResponse` struct.","ref":"MidiProto.Firmata.CapabilityResponse.html#init/1"},{"type":"type","title":"MidiProto.Firmata.CapabilityResponse.pin_mode/0","doc":"","ref":"MidiProto.Firmata.CapabilityResponse.html#t:pin_mode/0"},{"type":"type","title":"MidiProto.Firmata.CapabilityResponse.pin_resolution/0","doc":"","ref":"MidiProto.Firmata.CapabilityResponse.html#t:pin_resolution/0"},{"type":"type","title":"MidiProto.Firmata.CapabilityResponse.t/0","doc":"","ref":"MidiProto.Firmata.CapabilityResponse.html#t:t/0"},{"type":"module","title":"MidiProto.Firmata.ExtendedAnalog","doc":"Represents a Firmata extended analog message using a MIDI SysEx message.","ref":"MidiProto.Firmata.ExtendedAnalog.html"},{"type":"function","title":"MidiProto.Firmata.ExtendedAnalog.init/2","doc":"Initialise an `ExtendedAnalog` struct.","ref":"MidiProto.Firmata.ExtendedAnalog.html#init/2"},{"type":"type","title":"MidiProto.Firmata.ExtendedAnalog.t/0","doc":"","ref":"MidiProto.Firmata.ExtendedAnalog.html#t:t/0"},{"type":"module","title":"MidiProto.Firmata.FirmwareQuery","doc":"Represents a Firmata firmware query implemented using a MIDI SysEx message.","ref":"MidiProto.Firmata.FirmwareQuery.html"},{"type":"function","title":"MidiProto.Firmata.FirmwareQuery.init/0","doc":"Initialise a `FirmwareQuery` struct.","ref":"MidiProto.Firmata.FirmwareQuery.html#init/0"},{"type":"type","title":"MidiProto.Firmata.FirmwareQuery.t/0","doc":"","ref":"MidiProto.Firmata.FirmwareQuery.html#t:t/0"},{"type":"module","title":"MidiProto.Firmata.FirmwareResponse","doc":"Represents a Firmata firmware response using a MIDI SysEx message.","ref":"MidiProto.Firmata.FirmwareResponse.html"},{"type":"function","title":"MidiProto.Firmata.FirmwareResponse.init/3","doc":"Initialise a FirmwareResponse struct.","ref":"MidiProto.Firmata.FirmwareResponse.html#init/3"},{"type":"type","title":"MidiProto.Firmata.FirmwareResponse.t/0","doc":"","ref":"MidiProto.Firmata.FirmwareResponse.html#t:t/0"},{"type":"module","title":"MidiProto.Firmata.PinStateQuery","doc":"Represents a Firmata pin state query implemented using a MIDI SysEx message.","ref":"MidiProto.Firmata.PinStateQuery.html"},{"type":"function","title":"MidiProto.Firmata.PinStateQuery.init/1","doc":"Initialise a new `PinStateQuery` struct.","ref":"MidiProto.Firmata.PinStateQuery.html#init/1"},{"type":"type","title":"MidiProto.Firmata.PinStateQuery.t/0","doc":"","ref":"MidiProto.Firmata.PinStateQuery.html#t:t/0"},{"type":"module","title":"MidiProto.Firmata.PinStateResponse","doc":"Represents a Firmata pin state response implemented using a MIDI SysEx message.","ref":"MidiProto.Firmata.PinStateResponse.html"},{"type":"function","title":"MidiProto.Firmata.PinStateResponse.init/3","doc":"Initialise a new `PinStateResponse` struct.","ref":"MidiProto.Firmata.PinStateResponse.html#init/3"},{"type":"type","title":"MidiProto.Firmata.PinStateResponse.pin_mode/0","doc":"","ref":"MidiProto.Firmata.PinStateResponse.html#t:pin_mode/0"},{"type":"type","title":"MidiProto.Firmata.PinStateResponse.t/0","doc":"","ref":"MidiProto.Firmata.PinStateResponse.html#t:t/0"},{"type":"module","title":"MidiProto.Firmata.SamplingInterval","doc":"Represents the Firmata sampling interval message.","ref":"MidiProto.Firmata.SamplingInterval.html"},{"type":"function","title":"MidiProto.Firmata.SamplingInterval.init/1","doc":"Initialise a new `SamplingInterval` struct.","ref":"MidiProto.Firmata.SamplingInterval.html#init/1"},{"type":"type","title":"MidiProto.Firmata.SamplingInterval.t/0","doc":"","ref":"MidiProto.Firmata.SamplingInterval.html#t:t/0"},{"type":"module","title":"MidiProto.Firmata.String","doc":"Handles encoding and decoding strings (and binaries) using Firmata's two-byte\nencoding method.","ref":"MidiProto.Firmata.String.html"},{"type":"function","title":"MidiProto.Firmata.String.decode/1","doc":"Decode two-byte sequences back into a binary:","ref":"MidiProto.Firmata.String.html#decode/1"},{"type":"function","title":"Example - MidiProto.Firmata.String.decode/1","doc":"iex> <<0x4d, 0x00, 0x61, 0x00, 0x72, 0x00, 0x74, 0x00, 0x79, 0x00, 0x20, 0x00, 0x4d, 0x00, 0x63, 0x00, 0x46, 0x00, 0x6c, 0x00, 0x79, 0x00>>\n    ...> |> decode()\n    {:ok, \"Marty McFly\"}","ref":"MidiProto.Firmata.String.html#decode/1-example"},{"type":"function","title":"MidiProto.Firmata.String.encode/1","doc":"Encode binary values into two-byte sequences:","ref":"MidiProto.Firmata.String.html#encode/1"},{"type":"function","title":"Example - MidiProto.Firmata.String.encode/1","doc":"iex> \"Marty McFly\"\n    ...> |> encode()\n    {:ok, <<0x4d, 0x00, 0x61, 0x00, 0x72, 0x00, 0x74, 0x00, 0x79, 0x00, 0x20, 0x00, 0x4d, 0x00, 0x63, 0x00, 0x46, 0x00, 0x6c, 0x00, 0x79, 0x00>>}","ref":"MidiProto.Firmata.String.html#encode/1-example"},{"type":"module","title":"MidiProto.Firmata.StringData","doc":"Represents a Firmata string data message.","ref":"MidiProto.Firmata.StringData.html"},{"type":"function","title":"MidiProto.Firmata.StringData.init/1","doc":"Initialise a new `StringData` struct.","ref":"MidiProto.Firmata.StringData.html#init/1"},{"type":"type","title":"MidiProto.Firmata.StringData.t/0","doc":"","ref":"MidiProto.Firmata.StringData.html#t:t/0"},{"type":"module","title":"MidiProto.Firmata.UserDefined","doc":"Represents a Firmata user-defined command implemented using a MIDI SysEx message.","ref":"MidiProto.Firmata.UserDefined.html"},{"type":"function","title":"MidiProto.Firmata.UserDefined.init/2","doc":"Initialise a new `UserDefined` struct.","ref":"MidiProto.Firmata.UserDefined.html#init/2"},{"type":"type","title":"MidiProto.Firmata.UserDefined.command_id/0","doc":"","ref":"MidiProto.Firmata.UserDefined.html#t:command_id/0"},{"type":"type","title":"MidiProto.Firmata.UserDefined.t/0","doc":"","ref":"MidiProto.Firmata.UserDefined.html#t:t/0"},{"type":"protocol","title":"MidiProto.Message","doc":"Common behaviour for all MIDI message types.\n\nAllows you to check the capabilities of a MIDI message or encode it into a\nmessage for transmission.","ref":"MidiProto.Message.html"},{"type":"function","title":"MidiProto.Message.active_sense?/1","doc":"Is the message a active sense message?","ref":"MidiProto.Message.html#active_sense?/1"},{"type":"function","title":"MidiProto.Message.channel_pressure?/1","doc":"Is the message a channel pressure message?","ref":"MidiProto.Message.html#channel_pressure?/1"},{"type":"function","title":"MidiProto.Message.continue?/1","doc":"Is the message a continue message?","ref":"MidiProto.Message.html#continue?/1"},{"type":"function","title":"MidiProto.Message.control_change?/1","doc":"Is the message a control change message?","ref":"MidiProto.Message.html#control_change?/1"},{"type":"function","title":"MidiProto.Message.encode/1","doc":"Encode the message into a binary for sending.","ref":"MidiProto.Message.html#encode/1"},{"type":"function","title":"MidiProto.Message.note_off?/1","doc":"Is the message a note-off message?","ref":"MidiProto.Message.html#note_off?/1"},{"type":"function","title":"MidiProto.Message.note_on?/1","doc":"Is the message a note-on message?","ref":"MidiProto.Message.html#note_on?/1"},{"type":"function","title":"MidiProto.Message.pitch_bend?/1","doc":"Is the message a pitch bend message?","ref":"MidiProto.Message.html#pitch_bend?/1"},{"type":"function","title":"MidiProto.Message.polyphonic_pressure?/1","doc":"Is the message a polyphonic pressure message?","ref":"MidiProto.Message.html#polyphonic_pressure?/1"},{"type":"function","title":"MidiProto.Message.program_change?/1","doc":"Is the message a program change message?","ref":"MidiProto.Message.html#program_change?/1"},{"type":"function","title":"MidiProto.Message.realtime?/1","doc":"Is the message a realtime message?","ref":"MidiProto.Message.html#realtime?/1"},{"type":"function","title":"MidiProto.Message.song_position?/1","doc":"Is the message a song position message?","ref":"MidiProto.Message.html#song_position?/1"},{"type":"function","title":"MidiProto.Message.song_select?/1","doc":"Is the message a song select message?","ref":"MidiProto.Message.html#song_select?/1"},{"type":"function","title":"MidiProto.Message.start?/1","doc":"Is the message a start message?","ref":"MidiProto.Message.html#start?/1"},{"type":"function","title":"MidiProto.Message.stop?/1","doc":"Is the message a stop message?","ref":"MidiProto.Message.html#stop?/1"},{"type":"function","title":"MidiProto.Message.system?/1","doc":"Is the message a system message?","ref":"MidiProto.Message.html#system?/1"},{"type":"function","title":"MidiProto.Message.system_reset?/1","doc":"Is the message a system reset message?","ref":"MidiProto.Message.html#system_reset?/1"},{"type":"function","title":"MidiProto.Message.time_code_quarter_frame?/1","doc":"Is the message a time code quarter frame message?","ref":"MidiProto.Message.html#time_code_quarter_frame?/1"},{"type":"function","title":"MidiProto.Message.timing_clock?/1","doc":"Is the message a timing clock message?","ref":"MidiProto.Message.html#timing_clock?/1"},{"type":"function","title":"MidiProto.Message.tune_request?/1","doc":"Is the message a tune request message?","ref":"MidiProto.Message.html#tune_request?/1"},{"type":"type","title":"MidiProto.Message.t/0","doc":"All the types that implement this protocol.","ref":"MidiProto.Message.html#t:t/0"},{"type":"module","title":"MidiProto.Message.ActiveSense","doc":"A MIDI active sense system realtime message.","ref":"MidiProto.Message.ActiveSense.html"},{"type":"function","title":"MidiProto.Message.ActiveSense.init/0","doc":"Create a new MIDI active sense system realtime message.","ref":"MidiProto.Message.ActiveSense.html#init/0"},{"type":"type","title":"MidiProto.Message.ActiveSense.t/0","doc":"","ref":"MidiProto.Message.ActiveSense.html#t:t/0"},{"type":"module","title":"MidiProto.Message.ChannelPressure","doc":"A MIDI channel pressure message.","ref":"MidiProto.Message.ChannelPressure.html"},{"type":"function","title":"MidiProto.Message.ChannelPressure.init/2","doc":"Create a new MIDI channel pressure message with the provided parameters.","ref":"MidiProto.Message.ChannelPressure.html#init/2"},{"type":"type","title":"MidiProto.Message.ChannelPressure.t/0","doc":"","ref":"MidiProto.Message.ChannelPressure.html#t:t/0"},{"type":"module","title":"MidiProto.Message.Continue","doc":"A MIDI continue system realtime message.","ref":"MidiProto.Message.Continue.html"},{"type":"function","title":"MidiProto.Message.Continue.init/0","doc":"Create a new MIDI continue system realtime message.","ref":"MidiProto.Message.Continue.html#init/0"},{"type":"type","title":"MidiProto.Message.Continue.t/0","doc":"","ref":"MidiProto.Message.Continue.html#t:t/0"},{"type":"module","title":"MidiProto.Message.ControlChange","doc":"A MIDI control change message.","ref":"MidiProto.Message.ControlChange.html"},{"type":"function","title":"MidiProto.Message.ControlChange.init/3","doc":"Create a new MIDI control change message with the provided parameters.","ref":"MidiProto.Message.ControlChange.html#init/3"},{"type":"type","title":"MidiProto.Message.ControlChange.t/0","doc":"","ref":"MidiProto.Message.ControlChange.html#t:t/0"},{"type":"module","title":"MidiProto.Message.NoteOff","doc":"A MIDI note-off message.","ref":"MidiProto.Message.NoteOff.html"},{"type":"function","title":"MidiProto.Message.NoteOff.init/3","doc":"Create a new MIDI note-off message with the provided parameters.","ref":"MidiProto.Message.NoteOff.html#init/3"},{"type":"type","title":"MidiProto.Message.NoteOff.t/0","doc":"","ref":"MidiProto.Message.NoteOff.html#t:t/0"},{"type":"module","title":"MidiProto.Message.NoteOn","doc":"A MIDI note-on message.","ref":"MidiProto.Message.NoteOn.html"},{"type":"function","title":"MidiProto.Message.NoteOn.init/3","doc":"Create a new MIDI note-on message with the provided parameters.","ref":"MidiProto.Message.NoteOn.html#init/3"},{"type":"type","title":"MidiProto.Message.NoteOn.t/0","doc":"","ref":"MidiProto.Message.NoteOn.html#t:t/0"},{"type":"module","title":"MidiProto.Message.PitchBend","doc":"A MIDI pitch bend message.","ref":"MidiProto.Message.PitchBend.html"},{"type":"function","title":"MidiProto.Message.PitchBend.init/2","doc":"Create a new MIDI pitch bend message with the provided parameters.","ref":"MidiProto.Message.PitchBend.html#init/2"},{"type":"type","title":"MidiProto.Message.PitchBend.t/0","doc":"","ref":"MidiProto.Message.PitchBend.html#t:t/0"},{"type":"module","title":"MidiProto.Message.PolyphonicPressure","doc":"A MIDI polyphonic pressure message.","ref":"MidiProto.Message.PolyphonicPressure.html"},{"type":"function","title":"MidiProto.Message.PolyphonicPressure.init/3","doc":"Create a new MIDI polyphonic pressure message with the provided parameters.","ref":"MidiProto.Message.PolyphonicPressure.html#init/3"},{"type":"type","title":"MidiProto.Message.PolyphonicPressure.t/0","doc":"","ref":"MidiProto.Message.PolyphonicPressure.html#t:t/0"},{"type":"module","title":"MidiProto.Message.ProgramChange","doc":"A MIDI program change message.","ref":"MidiProto.Message.ProgramChange.html"},{"type":"function","title":"MidiProto.Message.ProgramChange.init/2","doc":"Create a new MIDI program change message with the provided parameters.","ref":"MidiProto.Message.ProgramChange.html#init/2"},{"type":"type","title":"MidiProto.Message.ProgramChange.t/0","doc":"","ref":"MidiProto.Message.ProgramChange.html#t:t/0"},{"type":"module","title":"MidiProto.Message.SongPosition","doc":"A MIDI song position message.","ref":"MidiProto.Message.SongPosition.html"},{"type":"function","title":"MidiProto.Message.SongPosition.init/1","doc":"Create a new MIDI song position message with the provided parameters.","ref":"MidiProto.Message.SongPosition.html#init/1"},{"type":"type","title":"MidiProto.Message.SongPosition.t/0","doc":"","ref":"MidiProto.Message.SongPosition.html#t:t/0"},{"type":"module","title":"MidiProto.Message.SongSelect","doc":"A MIDI song select message.","ref":"MidiProto.Message.SongSelect.html"},{"type":"function","title":"MidiProto.Message.SongSelect.init/1","doc":"Create a new MIDI song select message with the provided parameters.","ref":"MidiProto.Message.SongSelect.html#init/1"},{"type":"type","title":"MidiProto.Message.SongSelect.t/0","doc":"","ref":"MidiProto.Message.SongSelect.html#t:t/0"},{"type":"module","title":"MidiProto.Message.Start","doc":"A MIDI start system realtime message.","ref":"MidiProto.Message.Start.html"},{"type":"function","title":"MidiProto.Message.Start.init/0","doc":"Create a new MIDI start system realtime message.","ref":"MidiProto.Message.Start.html#init/0"},{"type":"type","title":"MidiProto.Message.Start.t/0","doc":"","ref":"MidiProto.Message.Start.html#t:t/0"},{"type":"module","title":"MidiProto.Message.Stop","doc":"A MIDI stop system realtime message.","ref":"MidiProto.Message.Stop.html"},{"type":"function","title":"MidiProto.Message.Stop.init/0","doc":"Create a new MIDI stop system realtime message.","ref":"MidiProto.Message.Stop.html#init/0"},{"type":"type","title":"MidiProto.Message.Stop.t/0","doc":"","ref":"MidiProto.Message.Stop.html#t:t/0"},{"type":"module","title":"MidiProto.Message.SystemExclusive","doc":"A MIDI System Exclusive (SysEx) message.","ref":"MidiProto.Message.SystemExclusive.html"},{"type":"function","title":"MidiProto.Message.SystemExclusive.init/2","doc":"Initialise a new System Exclusive message.\n\nThe payload parameter is a binary containing the payload to send.  Be aware\nthat the payload must be encoded such that the MSB of each byte is always zero\n(as per the MIDI spec).  The easiest way to do this is to just base64 encode\nyour data.","ref":"MidiProto.Message.SystemExclusive.html#init/2"},{"type":"type","title":"MidiProto.Message.SystemExclusive.t/0","doc":"","ref":"MidiProto.Message.SystemExclusive.html#t:t/0"},{"type":"type","title":"MidiProto.Message.SystemExclusive.vendor_id/0","doc":"","ref":"MidiProto.Message.SystemExclusive.html#t:vendor_id/0"},{"type":"module","title":"MidiProto.Message.SystemReset","doc":"A MIDI system reset system realtime message.","ref":"MidiProto.Message.SystemReset.html"},{"type":"function","title":"MidiProto.Message.SystemReset.init/0","doc":"Create a new MIDI system reset system realtime message.","ref":"MidiProto.Message.SystemReset.html#init/0"},{"type":"type","title":"MidiProto.Message.SystemReset.t/0","doc":"","ref":"MidiProto.Message.SystemReset.html#t:t/0"},{"type":"module","title":"MidiProto.Message.TimeCodeQuarterFrame","doc":"A MIDI time code quarter frame system realtime message.","ref":"MidiProto.Message.TimeCodeQuarterFrame.html"},{"type":"function","title":"MidiProto.Message.TimeCodeQuarterFrame.init/1","doc":"Create a new MIDI time code quarter frame system realtime message.","ref":"MidiProto.Message.TimeCodeQuarterFrame.html#init/1"},{"type":"type","title":"MidiProto.Message.TimeCodeQuarterFrame.t/0","doc":"","ref":"MidiProto.Message.TimeCodeQuarterFrame.html#t:t/0"},{"type":"module","title":"MidiProto.Message.TimingClock","doc":"A MIDI timing clock system realtime message.","ref":"MidiProto.Message.TimingClock.html"},{"type":"function","title":"MidiProto.Message.TimingClock.init/0","doc":"Create a new MIDI timing clock system realtime message.","ref":"MidiProto.Message.TimingClock.html#init/0"},{"type":"type","title":"MidiProto.Message.TimingClock.t/0","doc":"","ref":"MidiProto.Message.TimingClock.html#t:t/0"},{"type":"module","title":"MidiProto.Message.TuneRequest","doc":"A MIDI tune request system message.","ref":"MidiProto.Message.TuneRequest.html"},{"type":"function","title":"MidiProto.Message.TuneRequest.init/0","doc":"Create a new MIDI tune request system message.","ref":"MidiProto.Message.TuneRequest.html#init/0"},{"type":"type","title":"MidiProto.Message.TuneRequest.t/0","doc":"","ref":"MidiProto.Message.TuneRequest.html#t:t/0"},{"type":"module","title":"MidiProto.Parser","doc":"Parses incoming MIDI data.\n\nUse this module to parse incoming MIDI data from your device and it'll convert\nit to a stream of message structs for you.  Handy, eh?","ref":"MidiProto.Parser.html"},{"type":"module","title":"Usage - MidiProto.Parser","doc":"We split the receiving data and the parsing functions into separate functions\nso that you have the flexibility to handle incoming data without having pay\nthe cost of parsing until you're ready.\n\nHere's an example of parsing a single MIDI note on message:\n\n    iex> Parser.init()\n    ...> |> Parser.append(<<145, 2, 3>>)\n    ...> |> Parser.parse()\n    {:ok, [%MidiProto.Message.NoteOn{channel: 1, note_number: 2, velocity: 3}], %Parser{}}\n\nYou can call `append/2` and `parse/1` and number of times fill and empty the\nbuffer as required.","ref":"MidiProto.Parser.html#module-usage"},{"type":"function","title":"MidiProto.Parser.append/2","doc":"Append some new incoming data to the end of the parser buffer.\n\nUsually you append a packet at a time, but partial packets are fine, as long\nas they are completed before the call to `parse/1` is made.","ref":"MidiProto.Parser.html#append/2"},{"type":"function","title":"Example - MidiProto.Parser.append/2","doc":"iex> Parser.init()\n    ...> |> Parser.append(<<0xff>>)\n    %Parser{buffer: <<0xff>>}","ref":"MidiProto.Parser.html#append/2-example"},{"type":"function","title":"MidiProto.Parser.empty?/1","doc":"Check if the parse buffer is empty.","ref":"MidiProto.Parser.html#empty?/1"},{"type":"function","title":"MidiProto.Parser.init/0","doc":"Initialize an empty parser struct ready to receive data.\n\n    iex> Parser.init()\n    %Parser{}","ref":"MidiProto.Parser.html#init/0"},{"type":"function","title":"MidiProto.Parser.parse/1","doc":"Parse the contents of the buffer, returning zero or more messages.","ref":"MidiProto.Parser.html#parse/1"},{"type":"function","title":"Example - MidiProto.Parser.parse/1","doc":"iex> Parser.init()\n    ...> |> Parser.append(<<0xff>>)\n    ...> |> Parser.parse()\n    {:ok, [%SystemReset{}], %Parser{}}","ref":"MidiProto.Parser.html#parse/1-example"},{"type":"type","title":"MidiProto.Parser.t/0","doc":"","ref":"MidiProto.Parser.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}